@@ -1,11 +1,11 @@
 /***************************************************************************
-	File                 : ScriptingLangDialog.cpp
-	Project              : SciDAVis
+        File                 : ScriptingLangDialog.cpp
+        Project              : SciDAVis
 --------------------------------------------------------------------
-	Copyright            : (C) 2006 by Knut Franke, Ion Vasilief
-	Email (use @ for *)  : knut.franke*gmx.de, ion_vasilief*yahoo.fr
-	Description          : Dialog for changing the current scripting
-	                       language
+        Copyright            : (C) 2006 by Knut Franke, Ion Vasilief
+        Email (use @ for *)  : knut.franke*gmx.de, ion_vasilief*yahoo.fr
+        Description          : Dialog for changing the current scripting
+                               language
 
  ***************************************************************************/
 
@@ -35,48 +35,50 @@
 #include <QLayout>
 #include <QMessageBox>
 
-ScriptingLangDialog::ScriptingLangDialog(ScriptingEnv *env, ApplicationWindow *parent, Qt::WindowFlags fl )
-: QDialog(parent, fl), scripted(env)
+ScriptingLangDialog::ScriptingLangDialog(ScriptingEnv *env, ApplicationWindow *parent,
+                                         Qt::WindowFlags fl)
+    : QDialog(parent, fl), scripted(env)
 {
-	setWindowTitle(tr("Select scripting language"));
+    setWindowTitle(tr("Select scripting language"));
 
-	langList = new QListWidget(this);
+    langList = new QListWidget(this);
 
-	btnOK = new QPushButton(tr("OK"));
-	btnCancel = new QPushButton(tr("Cancel"));
+    btnOK = new QPushButton(tr("OK"));
+    btnCancel = new QPushButton(tr("Cancel"));
 
-	QHBoxLayout *hbox1 = new QHBoxLayout(); 
+    QHBoxLayout *hbox1 = new QHBoxLayout();
     hbox1->addStretch();
-	hbox1->addWidget(btnOK);
-	hbox1->addWidget(btnCancel);
+    hbox1->addWidget(btnOK);
+    hbox1->addWidget(btnCancel);
 
-	QVBoxLayout *vl = new QVBoxLayout(this);
-	vl->addWidget(langList);
-	vl->addLayout(hbox1);	
+    QVBoxLayout *vl = new QVBoxLayout(this);
+    vl->addWidget(langList);
+    vl->addLayout(hbox1);
 
-	connect(btnOK, SIGNAL(clicked()), this, SLOT(accept()));
-	connect(btnCancel, SIGNAL(clicked()), this, SLOT(close()));
-	connect(langList, SIGNAL(itemActivated(QListWidgetItem*)), this, SLOT(accept()));
+    connect(btnOK, SIGNAL(clicked()), this, SLOT(accept()));
+    connect(btnCancel, SIGNAL(clicked()), this, SLOT(close()));
+    connect(langList, SIGNAL(itemActivated(QListWidgetItem *)), this, SLOT(accept()));
 
-	updateLangList();
+    updateLangList();
 }
 
 void ScriptingLangDialog::updateLangList()
 {
-	langList->clear();
-	langList->insertItems(0, ScriptingLangManager::languages());
-	QListWidgetItem *current = langList->findItems(scriptEnv->objectName(), Qt::MatchExactly).first();
-	if (current)
-		langList->setCurrentItem(current);
+    langList->clear();
+    langList->insertItems(0, ScriptingLangManager::languages());
+    QListWidgetItem *current =
+            langList->findItems(scriptEnv->objectName(), Qt::MatchExactly).first();
+    if (current)
+        langList->setCurrentItem(current);
 }
 
 void ScriptingLangDialog::accept()
 {
-	ApplicationWindow *app = (ApplicationWindow*) parent();
-	if (app->setScriptingLang(langList->currentItem()->text()))
-		close();
-	else
-		QMessageBox::critical(this, tr("Scripting Error"),
-				tr("Scripting language \"%1\" failed to initialize.").arg(langList->currentItem()->text()));
+    ApplicationWindow *app = (ApplicationWindow *)parent();
+    if (app->setScriptingLang(langList->currentItem()->text()))
+        close();
+    else
+        QMessageBox::critical(this, tr("Scripting Error"),
+                              tr("Scripting language \"%1\" failed to initialize.")
+                                      .arg(langList->currentItem()->text()));
 }
-
